# IotCentral

> see https://aka.ms/autorest

This is the AutoRest configuration file for IotCentral.

---

## Getting Started

To build the SDK for IotCentral, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

## Configuration

### Basic Information

These are the global settings for IotCentral.

``` yaml
openapi-type: arm
tag: package-2021-06
```


### Tag: package-2021-06

These settings apply only when `--tag=package-2021-06` is specified on the command line.

```yaml $(tag) == 'package-2021-06'
input-file:
  - Microsoft.IoTCentral/stable/2021-06-01/iotcentral.json
directive:
  - suppress: R4009
    from: iotcentral.json
    reason: We do not yet support systemdata.
  - suppress: R3018
    from: iotcentral.json
    reason: resource name availability needs to be boolean (available or not)
  - suppress: R4018
    from: iotcentral.json
    reason: We do not yet support isDataAction, display.description and display.resource.
```
### Tag: package-2018-09-01

These settings apply only when `--tag=package-2018-09-01` is specified on the command line.

``` yaml $(tag) == 'package-2018-09-01'
input-file:
- Microsoft.IoTCentral/stable/2018-09-01/iotcentral.json
```

### Tag: package-2017-07-01-privatepreview

These settings apply only when `--tag=package-2017-07-01-privatepreview` is specified on the command line.

``` yaml $(tag) == 'package-2017-07-01-privatepreview'
input-file:
- Microsoft.IoTCentral/preview/2017-07-01-privatepreview/iotcentral.json
```

---

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-net
  - repo: azure-sdk-for-python-track2
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_iot_central']
  - repo: azure-resource-manager-schemas
```

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.IotCentral
  payload-flattening-threshold: 1
  output-folder: $(csharp-sdks-folder)/iotcentral/Microsoft.Azure.Management.IotCentral/src/Generated
  clear-output-folder: true
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.iotcentral
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-iotcentral
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2018-09-01
  - tag: package-2017-07-01-privatepreview
```

### Tag: package-2018-09-01 and java

These settings apply only when `--tag=package-2018-09-01 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag)=='package-2018-09-01' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.iotcentral.v2018_09_01
  output-folder: $(azure-libraries-for-java-folder)/sdk/iotcentral/mgmt-v2018_09_01
regenerate-manager: true
generate-interface: true
```

### Tag: package-2017-07-01-privatepreview and java

These settings apply only when `--tag=package-2017-07-01-privatepreview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag)=='package-2017-07-01-privatepreview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.iotcentral.v2017_07_01_privatepreview
  output-folder: $(azure-libraries-for-java-folder)/sdk/iotcentral/mgmt-v2017_07_01_privatepreview
regenerate-manager: true
generate-interface: true
```
